(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-highlight-js', ['exports', '@angular/core', '@angular/common'], factory) :
    (global = global || self, factory(global['ngx-highlight-js'] = {}, global.ng.core, global.ng.common));
}(this, (function (exports, core, common) { 'use strict';

    var AbmConfig = /** @class */ (function () {
        function AbmConfig() {
        }
        return AbmConfig;
    }());

    var LoaderService = /** @class */ (function () {
        function LoaderService(cog, doc) {
            this.doc = doc;
            this._cog = Object.assign({ apiProtocol: 'auto', apiVersion: '3.0', apiCallback: 'angularBaiduMapsLoader', apiHostAndPath: 'api.map.baidu.com/api' }, cog);
        }
        LoaderService.prototype.load = function () {
            var _this = this;
            if (this._scriptLoadingPromise) {
                return this._scriptLoadingPromise;
            }
            var script = this.doc.createElement('script');
            script.type = 'text/javascript';
            script.async = true;
            script.defer = true;
            script.src = this._getSrc();
            this._scriptLoadingPromise = new Promise(function (resolve, reject) {
                window[_this._cog.apiCallback] = function () {
                    resolve();
                };
                script.onerror = function (error) {
                    reject(error);
                };
            });
            this.doc.body.appendChild(script);
            return this._scriptLoadingPromise;
        };
        LoaderService.prototype._getSrc = function () {
            var protocol;
            switch (this._cog.apiProtocol) {
                case 'http':
                    protocol = 'http:';
                    break;
                case 'https':
                    protocol = 'https:';
                    break;
                case 'file':
                    protocol = 'file:';
                    break;
                default:
                    protocol = '';
                    break;
            }
            var queryParams = {
                v: this._cog.apiVersion,
                ak: this._cog.apiKey,
                callback: this._cog.apiCallback,
            };
            var params = Object.keys(queryParams)
                .filter(function (k) { return queryParams[k] != null; })
                .filter(function (k) {
                return (!Array.isArray(queryParams[k]) ||
                    (Array.isArray(queryParams[k]) && queryParams[k].length > 0));
            })
                .map(function (k) {
                var i = queryParams[k];
                if (Array.isArray(i)) {
                    return { key: k, value: i.join(',') };
                }
                return { key: k, value: i };
            })
                .map(function (entry) {
                return entry.key + "=" + entry.value;
            })
                .join('&');
            return protocol + "//" + this._cog.apiHostAndPath + "?" + params;
        };
        return LoaderService;
    }());
    LoaderService.decorators = [
        { type: core.Injectable }
    ];
    LoaderService.ctorParameters = function () { return [
        { type: AbmConfig },
        { type: undefined, decorators: [{ type: core.Inject, args: [common.DOCUMENT,] }] }
    ]; };

    var AbmComponent = /** @class */ (function () {
        function AbmComponent(el, COG, loader, zone) {
            this.el = el;
            this.COG = COG;
            this.loader = loader;
            this.zone = zone;
            this.options = {};
            this.ready = new core.EventEmitter();
            this.map = null;
        }
        AbmComponent.prototype.ngOnInit = function () {
            if (!(typeof document === 'object' && !!document)) {
                return;
            }
            this._initMap();
        };
        AbmComponent.prototype.ngOnChanges = function (changes) {
            if ('options' in changes) {
                this._updateOptions();
            }
        };
        AbmComponent.prototype._initMap = function () {
            var _this = this;
            if (this.map) {
                return;
            }
            this.loader
                .load()
                .then(function () {
                _this.zone.runOutsideAngular(function () {
                    try {
                        _this.map = new BMap.Map(_this.el.nativeElement, _this.options);
                    }
                    catch (ex) {
                        console.warn('地图初始化失败', ex);
                    }
                });
                _this.ready.emit(_this.map);
            })
                .catch(function (error) {
                console.warn('js加载失败', error);
            });
        };
        AbmComponent.prototype._updateOptions = function () {
            this.options = Object.assign(Object.assign({}, this.COG.mapOptions), this.options);
            if (this.map) {
                this.map.setOptions(this.options);
            }
        };
        AbmComponent.prototype.destroy = function () {
            if (this.map) {
                this.map.clearOverlays();
                this.map.clearHotspots();
            }
        };
        AbmComponent.prototype.ngOnDestroy = function () {
            this.destroy();
        };
        return AbmComponent;
    }());
    AbmComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'abm-map',
                    template: "",
                    host: {
                        '[class.angular-baidu-maps-container]': 'true',
                    },
                    encapsulation: core.ViewEncapsulation.None,
                    styles: ["\n      .angular-baidu-maps-container {\n        display: block;\n        width: 100%;\n        height: 100%;\n      }\n    "]
                },] }
    ];
    AbmComponent.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: AbmConfig },
        { type: LoaderService },
        { type: core.NgZone }
    ]; };
    AbmComponent.propDecorators = {
        options: [{ type: core.Input }],
        ready: [{ type: core.Output }]
    };

    var AbmPanoramaComponent = /** @class */ (function () {
        function AbmPanoramaComponent(el, COG, loader, zone) {
            this.el = el;
            this.COG = COG;
            this.loader = loader;
            this.zone = zone;
            this.options = {};
            this.ready = new core.EventEmitter();
            this.map = null;
        }
        AbmPanoramaComponent.prototype.ngOnInit = function () {
            if (!(typeof document === 'object' && !!document)) {
                return;
            }
            this._initMap();
        };
        AbmPanoramaComponent.prototype.ngOnChanges = function (changes) {
            if ('options' in changes) {
                this._updateOptions();
            }
        };
        AbmPanoramaComponent.prototype._initMap = function () {
            var _this = this;
            if (this.map) {
                return;
            }
            this.loader
                .load()
                .then(function () {
                _this.zone.runOutsideAngular(function () {
                    try {
                        _this.map = new BMap.Panorama(_this.el.nativeElement, _this.options);
                    }
                    catch (ex) {
                        console.warn('全景初始化失败', ex);
                    }
                });
                _this.ready.emit(_this.map);
            })
                .catch(function (error) {
                console.warn('js加载失败', error);
            });
        };
        AbmPanoramaComponent.prototype._updateOptions = function () {
            this.options = Object.assign(Object.assign({}, this.COG.panoramaOptions), this.options);
            if (this.map) {
                this.map.setOptions(this.options);
            }
        };
        AbmPanoramaComponent.prototype.destroy = function () { };
        AbmPanoramaComponent.prototype.ngOnDestroy = function () {
            this.destroy();
        };
        return AbmPanoramaComponent;
    }());
    AbmPanoramaComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'abm-panorama',
                    template: "",
                    host: {
                        '[class.angular-baidu-maps-container]': 'true',
                    },
                    encapsulation: core.ViewEncapsulation.None,
                    styles: ["\n      .angular-baidu-maps-container {\n        display: block;\n        width: 100%;\n        height: 100%;\n      }\n    "]
                },] }
    ];
    AbmPanoramaComponent.ctorParameters = function () { return [
        { type: core.ElementRef },
        { type: AbmConfig },
        { type: LoaderService },
        { type: core.NgZone }
    ]; };
    AbmPanoramaComponent.propDecorators = {
        options: [{ type: core.Input }],
        ready: [{ type: core.Output }]
    };

    var AbmModule = /** @class */ (function () {
        function AbmModule() {
        }
        AbmModule.forRoot = function (config) {
            return {
                ngModule: AbmModule,
                providers: [{ provide: AbmConfig, useValue: config }],
            };
        };
        return AbmModule;
    }());
    AbmModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [common.CommonModule],
                    providers: [LoaderService],
                    declarations: [AbmComponent, AbmPanoramaComponent],
                    exports: [AbmComponent, AbmPanoramaComponent],
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.AbmComponent = AbmComponent;
    exports.AbmConfig = AbmConfig;
    exports.AbmModule = AbmModule;
    exports.AbmPanoramaComponent = AbmPanoramaComponent;
    exports.ɵa = LoaderService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-highlight-js.umd.js.map
