import { Injectable, Inject, EventEmitter, Component, ViewEncapsulation, ElementRef, NgZone, Input, Output, NgModule } from '@angular/core';
import { DOCUMENT, CommonModule } from '@angular/common';

class AbmConfig {
}

class LoaderService {
    constructor(cog, doc) {
        this.doc = doc;
        this._cog = Object.assign({ apiProtocol: 'auto', apiVersion: '3.0', apiCallback: 'angularBaiduMapsLoader', apiHostAndPath: 'api.map.baidu.com/api' }, cog);
    }
    load() {
        if (this._scriptLoadingPromise) {
            return this._scriptLoadingPromise;
        }
        const script = this.doc.createElement('script');
        script.type = 'text/javascript';
        script.async = true;
        script.defer = true;
        script.src = this._getSrc();
        this._scriptLoadingPromise = new Promise((resolve, reject) => {
            window[this._cog.apiCallback] = () => {
                resolve();
            };
            script.onerror = (error) => {
                reject(error);
            };
        });
        this.doc.body.appendChild(script);
        return this._scriptLoadingPromise;
    }
    _getSrc() {
        let protocol;
        switch (this._cog.apiProtocol) {
            case 'http':
                protocol = 'http:';
                break;
            case 'https':
                protocol = 'https:';
                break;
            case 'file':
                protocol = 'file:';
                break;
            default:
                protocol = '';
                break;
        }
        const queryParams = {
            v: this._cog.apiVersion,
            ak: this._cog.apiKey,
            callback: this._cog.apiCallback,
        };
        const params = Object.keys(queryParams)
            .filter((k) => queryParams[k] != null)
            .filter((k) => {
            return (!Array.isArray(queryParams[k]) ||
                (Array.isArray(queryParams[k]) && queryParams[k].length > 0));
        })
            .map((k) => {
            const i = queryParams[k];
            if (Array.isArray(i)) {
                return { key: k, value: i.join(',') };
            }
            return { key: k, value: i };
        })
            .map((entry) => {
            return `${entry.key}=${entry.value}`;
        })
            .join('&');
        return `${protocol}//${this._cog.apiHostAndPath}?${params}`;
    }
}
LoaderService.decorators = [
    { type: Injectable }
];
LoaderService.ctorParameters = () => [
    { type: AbmConfig },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

class AbmComponent {
    constructor(el, COG, loader, zone) {
        this.el = el;
        this.COG = COG;
        this.loader = loader;
        this.zone = zone;
        this.options = {};
        this.ready = new EventEmitter();
        this.map = null;
    }
    ngOnInit() {
        if (!(typeof document === 'object' && !!document)) {
            return;
        }
        this._initMap();
    }
    ngOnChanges(changes) {
        if ('options' in changes) {
            this._updateOptions();
        }
    }
    _initMap() {
        if (this.map) {
            return;
        }
        this.loader
            .load()
            .then(() => {
            this.zone.runOutsideAngular(() => {
                try {
                    this.map = new BMap.Map(this.el.nativeElement, this.options);
                }
                catch (ex) {
                    console.warn('地图初始化失败', ex);
                }
            });
            this.ready.emit(this.map);
        })
            .catch((error) => {
            console.warn('js加载失败', error);
        });
    }
    _updateOptions() {
        this.options = Object.assign(Object.assign({}, this.COG.mapOptions), this.options);
        if (this.map) {
            this.map.setOptions(this.options);
        }
    }
    destroy() {
        if (this.map) {
            this.map.clearOverlays();
            this.map.clearHotspots();
        }
    }
    ngOnDestroy() {
        this.destroy();
    }
}
AbmComponent.decorators = [
    { type: Component, args: [{
                selector: 'abm-map',
                template: ``,
                host: {
                    '[class.angular-baidu-maps-container]': 'true',
                },
                encapsulation: ViewEncapsulation.None,
                styles: [`
      .angular-baidu-maps-container {
        display: block;
        width: 100%;
        height: 100%;
      }
    `]
            },] }
];
AbmComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: AbmConfig },
    { type: LoaderService },
    { type: NgZone }
];
AbmComponent.propDecorators = {
    options: [{ type: Input }],
    ready: [{ type: Output }]
};

class AbmPanoramaComponent {
    constructor(el, COG, loader, zone) {
        this.el = el;
        this.COG = COG;
        this.loader = loader;
        this.zone = zone;
        this.options = {};
        this.ready = new EventEmitter();
        this.map = null;
    }
    ngOnInit() {
        if (!(typeof document === 'object' && !!document)) {
            return;
        }
        this._initMap();
    }
    ngOnChanges(changes) {
        if ('options' in changes) {
            this._updateOptions();
        }
    }
    _initMap() {
        if (this.map) {
            return;
        }
        this.loader
            .load()
            .then(() => {
            this.zone.runOutsideAngular(() => {
                try {
                    this.map = new BMap.Panorama(this.el.nativeElement, this.options);
                }
                catch (ex) {
                    console.warn('全景初始化失败', ex);
                }
            });
            this.ready.emit(this.map);
        })
            .catch((error) => {
            console.warn('js加载失败', error);
        });
    }
    _updateOptions() {
        this.options = Object.assign(Object.assign({}, this.COG.panoramaOptions), this.options);
        if (this.map) {
            this.map.setOptions(this.options);
        }
    }
    destroy() { }
    ngOnDestroy() {
        this.destroy();
    }
}
AbmPanoramaComponent.decorators = [
    { type: Component, args: [{
                selector: 'abm-panorama',
                template: ``,
                host: {
                    '[class.angular-baidu-maps-container]': 'true',
                },
                encapsulation: ViewEncapsulation.None,
                styles: [`
      .angular-baidu-maps-container {
        display: block;
        width: 100%;
        height: 100%;
      }
    `]
            },] }
];
AbmPanoramaComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: AbmConfig },
    { type: LoaderService },
    { type: NgZone }
];
AbmPanoramaComponent.propDecorators = {
    options: [{ type: Input }],
    ready: [{ type: Output }]
};

class AbmModule {
    static forRoot(config) {
        return {
            ngModule: AbmModule,
            providers: [{ provide: AbmConfig, useValue: config }],
        };
    }
}
AbmModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                providers: [LoaderService],
                declarations: [AbmComponent, AbmPanoramaComponent],
                exports: [AbmComponent, AbmPanoramaComponent],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { AbmComponent, AbmConfig, AbmModule, AbmPanoramaComponent, LoaderService as ɵa };
//# sourceMappingURL=ngx-highlight-js.js.map
